@@ -13,12 +13,25 @@ class TTLCache(LRUCache):
 
     This class associates a time-to-live value with each item.  Items
     that expire because they have exceeded their time-to-live will be
-    removed automatically.  If no expired items are there to remove,
-    the least recently used items will be discarded first to make
-    space when necessary.
+    removed.  If no expired items are there to remove, the least
+    recently used items will be discarded first to make space when
+    necessary.
+
+    By default, the time-to-live is specified in seconds, and the
+    standard :func:`time.time` function is used to retrieve the
+    current time.  A custom `timer` function can be supplied if
+    needed.
 
     """
 
+    class ExpiredError(KeyError):
+        """Raised when a cached item's time-to-live has expired.
+
+        This is a subclass of :exc:`KeyError`.
+
+        """
+        pass
+
     def __init__(self, maxsize, ttl, timer=time.time, getsizeof=None):
         if getsizeof is None:
             LRUCache.__init__(self, maxsize)
@@ -42,7 +55,7 @@ class TTLCache(LRUCache):
     def __getitem__(self, key, cache_getitem=LRUCache.__getitem__):
         value, link = cache_getitem(self, key)
         if link.data[1] < self.__timer():
-            raise KeyError(key)
+            raise TTLCache.ExpiredError(key)
         return value
 
     def __setitem__(self, key, value,
@@ -75,15 +88,16 @@ class TTLCache(LRUCache):
         link.unlink()
         self.expire()
 
-    @property
-    def ttl(self):
-        """Return the time-to-live of the cache."""
-        return self.__ttl
-
-    @property
-    def timer(self):
-        """Return the timer used by the cache."""
-        return self.__timer
+    def expire(self, time=None, cache_delitem=LRUCache.__delitem__):
+        """Remove expired items from the cache."""
+        if time is None:
+            time = self.__timer()
+        root = self.__root
+        head = root.next
+        while head is not root and head.data[1] < time:
+            cache_delitem(self, head.data[0])
+            head.next.prev = root
+            head = root.next = head.next
 
     def pop(self, key, default=_marker):
         try:
@@ -97,15 +111,15 @@ class TTLCache(LRUCache):
         self.expire()
         return value
 
-    def expire(self, time=None, cache_delitem=LRUCache.__delitem__):
-        if time is None:
-            time = self.__timer()
-        root = self.__root
-        head = root.next
-        while head is not root and head.data[1] < time:
-            cache_delitem(self, head.data[0])
-            head.next.prev = root
-            head = root.next = head.next
+    @property
+    def timer(self):
+        """Return the timer used by the cache."""
+        return self.__timer
+
+    @property
+    def ttl(self):
+        """Return the time-to-live of the cache."""
+        return self.__ttl
 
 
 def ttl_cache(maxsize=128, ttl=600, timer=time.time, typed=False,
@@ -114,4 +128,4 @@ def ttl_cache(maxsize=128, ttl=600, timer=time.time, typed=False,
     up to `maxsize` results based on a Least Recently Used (LRU)
     algorithm with a per-item time-to-live (TTL) value.
     """
-    return cachedfunc(TTLCache(maxsize, ttl, timer, getsizeof), typed, lock())
+    return cachedfunc(TTLCache(maxsize, ttl, timer, getsizeof), typed, lock)
