@@ -6,10 +6,11 @@ from cachetools import LRUCache, cachedmethod
 
 class Cached(object):
 
-    cache = LRUCache(maxsize=2)
-
     count = 0
 
+    def __init__(self, cache):
+        self.cache = cache
+
     @cachedmethod(operator.attrgetter('cache'))
     def get(self, value):
         count = self.count
@@ -26,7 +27,8 @@ class Cached(object):
 class CachedMethodTest(unittest.TestCase):
 
     def test_decorator(self):
-        cached = Cached()
+        cached = Cached(LRUCache(maxsize=2))
+        self.assertEqual(cached.cache, cached.get.cache(cached))
 
         self.assertEqual(cached.get(0), 0)
         self.assertEqual(cached.get(1), 1)
@@ -38,7 +40,8 @@ class CachedMethodTest(unittest.TestCase):
         self.assertEqual(cached.get(1), 2)
 
     def test_typed_decorator(self):
-        cached = Cached()
+        cached = Cached(LRUCache(maxsize=2))
+        self.assertEqual(cached.cache, cached.get_typed.cache(cached))
 
         self.assertEqual(cached.get_typed(0), 0)
         self.assertEqual(cached.get_typed(1), 1)
@@ -47,3 +50,13 @@ class CachedMethodTest(unittest.TestCase):
         self.assertEqual(cached.get_typed(1.0), 2)
         self.assertEqual(cached.get_typed(0.0), 3)
         self.assertEqual(cached.get_typed(0), 4)
+
+    def test_decorator_nocache(self):
+        cached = Cached(None)
+        self.assertEqual(None, cached.get.cache(cached))
+
+        self.assertEqual(cached.get(0), 0)
+        self.assertEqual(cached.get(1), 1)
+        self.assertEqual(cached.get(1), 2)
+        self.assertEqual(cached.get(1.0), 3)
+        self.assertEqual(cached.get(1.0), 4)
